diff --git a/src/devices/Lis3Dh/Lis3Dh.cs b/src/devices/Lis3Dh/Lis3Dh.cs
index a576e1ee1d..3e9be5c9d5 100644
--- a/src/devices/Lis3Dh/Lis3Dh.cs
+++ b/src/devices/Lis3Dh/Lis3Dh.cs
@@ -130,7 +130,7 @@ private void ChangeSettings(DataRate dataRate, OperatingMode operatingMode, Acce
byte lowPowerModeBitAndAxesEnable = (byte)(operatingMode == OperatingMode.LowPowerMode ? 0b1111 : 0b0111);
this[Register.CTRL_REG1] = (byte)(dataRateBits | lowPowerModeBitAndAxesEnable);
- // remainder of the bits (block data update/endianess/self-test/SPI 3 or 4-wire setting) set to default
+ // remainder of the bits (block data update/endianness/self-test/SPI 3 or 4-wire setting) set to default
byte fullScaleBits = (byte)((byte)accelerationScale << 4);
byte highResolutionModeBit = (byte)(operatingMode == OperatingMode.HighResolutionMode ? 0b1000 : 0b0000);
this[Register.CTRL_REG4] = (byte)(fullScaleBits | highResolutionModeBit);
diff --git a/tools/ArduinoCsCompiler/Runtime/MiniBitConverter.cs b/tools/ArduinoCsCompiler/Runtime/MiniBitConverter.cs
index ea14a0a5fe..058f29cdd0 100644
--- a/tools/ArduinoCsCompiler/Runtime/MiniBitConverter.cs
+++ b/tools/ArduinoCsCompiler/Runtime/MiniBitConverter.cs
@@ -9,7 +9,7 @@ namespace ArduinoCsCompiler.Runtime
[ArduinoReplacement(typeof(BitConverter), true)]
internal class MiniBitConverter
{
- // This must be set to the endianess of the target platform, but currently all Microcontrollers that are supported seem to use little endian
+ // This must be set to the endianness of the target platform, but currently all Microcontrollers that are supported seem to use little endian
public static readonly bool IsLittleEndian = true;
[ArduinoImplementation("BitConverterSingleToInt32Bits")]
diff --git a/src/devices/Nmea0183/Sentences/ProprietaryMessage.cs b/src/devices/Nmea0183/Sentences/ProprietaryMessage.cs
index 3a4d211466..6a6061af46 100644
--- a/src/devices/Nmea0183/Sentences/ProprietaryMessage.cs
+++ b/src/devices/Nmea0183/Sentences/ProprietaryMessage.cs
@@ -52,7 +52,7 @@ public abstract int Identifier
get;
}
- private static UInt32 InverseEndianess(UInt32 value)
+ private static UInt32 InverseEndianness(UInt32 value)
{
return (value & 0x000000FFU) << 24 | (value & 0x0000FF00U) << 8 |
(value & 0x00FF0000U) >> 8 | (value & 0xFF000000U) >> 24;
@@ -64,7 +64,7 @@ private static UInt32 InverseEndianess(UInt32 value)
/// Input string
/// Start offset of required number
/// Length of required number. Must be 2, 4 or 8
/// True to inverse the endianess of the number (reverse the partial string)
/// The output value
/// True on success, false otherwise
/// Length is not 2, 4 or 8
@@ -72,7 +72,7 @@ private static UInt32 InverseEndianess(UInt32 value)
/// Other erroneous inputs don't throw an exception but return false, e.g. string shorter than expected or
/// value is not a hex number. This is to prevent an exception in case of a malformed message.
///
- protected bool ReadFromHexString(string input, int start, int length, bool inverseEndianess, out int value)
+ protected bool ReadFromHexString(string input, int start, int length, bool inverseEndianness, out int value)
{
if (length != 2 && length != 4 && length != 8)
{
@@ -94,11 +94,11 @@ protected bool ReadFromHexString(string input, int start, int length, bool inver
return false;
}
- if (length == 8 && inverseEndianess)
+ if (length == 8 && inverseEndianness)
{
- result = InverseEndianess(result);
+ result = InverseEndianness(result);
}
- else if (length == 4 && inverseEndianess)
+ else if (length == 4 && inverseEndianness)
{
result = result >> 8 | ((result & 0xFF) << 8);
}
@@ -64,7 +64,7 @@ private static UInt32 InverseEndianess(UInt32 value)
/// Start offset of required number
/// Length of required number. Must be 2, 4 or 8
- /// True to inverse the endianess of the number (reverse the partial string)
+ /// True to inverse the endianness of the number (reverse the partial string)
/// The output value
/// True on success, false otherwise